@@ -1,5 +1,9 @@
 from contextvars import ContextVar
 
+__version__ = "0.2.3"
+__author__ = "Tomasz Wojcik"
+
+
 _request_scope_context_storage: ContextVar[str] = ContextVar(
     "starlette_context"
 )
